/*
 * Copyright (C) 2006 Andre Noll <maan@tuebingen.mpg.de>
 *
 * Licensed under the GPL v2. For licencing details see COPYING.
 */

/** \file user_list.h exported functions from user_list.c */

/**
 * Flags for server commands and user permissions.
 *
 * For each command, zero or more of these flags are ored to define the command
 * permissions. A user is allowed to run the command if and only if all command
 * permission flags are set for the user in the server.users config file which
 * is read at server startup.
 */
enum server_command_permissions {
	NO_PERMISSION_REQUIRED = 0, /** None of the below. */
	AFS_READ = 1, /** Read-only operation on the AFS database. */
	AFS_WRITE = 2, /** Read-write operation on the AFS database. */
	VSS_READ = 4, /** Read-only operation on the virtual streaming system. */
	VSS_WRITE = 8 /** Read-write operation on the virtual streaming system. */
};

/**
 * data needed to authenticate the user
 */
struct user {
	/** The position of this user in the list of users. */
	struct list_head node;
	/** The username. */
	char *name;
	/** The public key. */
	struct asymmetric_key *pubkey;
	/** The privileges of this user. */
	unsigned int perms;
};

void init_user_list(char *user_list_file);
struct user *lookup_user(const char *name);
